==> dosage_1.5.2.orig.tar.gz: dosage-1.5.2/dosage/modules/KeenSpot.py <==
import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class KeenSpot(BasicComicModule):
    imageUrl = 'd/%s.html'
    imageSearch = re.compile(r'<img[^>]+?src="([^"]*?comics/.+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="([^"]*?d/\d{8}\.html)">(?:<img[^>]+?(?:name="previous_day"|src="[^"]*back[^"]*")|Previous comic)', re.IGNORECASE)
    help = 'Index format: yyyymmdd'

    submodules = {
        '24fps': 'http://filmbuff.keenspace.com/',
        'Adventurers': 'http://www.adventurers-comic.com/',
        'Alice': 'http://www.alicecomics.com/',
        'AlienDice': 'http://www.aliendice.com/',
        'AntiHeroForHire': 'http://www.antiheroforhire.com/',
        'Avalon': 'http://www.avalonhigh.com/',
        'BasilFlint': 'http://www.basilflint.com/',
        'Blindworks': 'http://blindworks.keenspace.com/',
        'BoomerExpress': 'http://boomerexpress.keenspace.com/',
        'BoyMeetsBoy': 'http://boymeetsboy.keenspot.com/',
        'CheckerboardNightmare': 'http://www.checkerboardnightmare.com/',
        'ChoppingBlock': 'http://choppingblock.org/',
        'ClanOfTheCats': 'http://www.clanofthecats.com/',
        'CollegeRoomiesFromHell': 'http://www.crfh.net/',
        'CountYourSheep': 'http://www.countyoursheep.com/',
        'DeltaVenture': 'http://www.alicecomics.com/adv',
        'DexLives': 'http://dexlives.keenspace.com/',
        'DominicDeegan': 'http://www.dominic-deegan.com/',
        'ElfLife': 'http://www.elflife.com/',
        'ElfOnlyInn': 'http://www.elfonlyinn.net/',
        'ElGoonishShive': 'http://elgoonishshive.com/',
        'ErrantStory': 'http://www.errantstory.com/',
        'EverythingJake': 'http://www.everythingjake.com/',
        'ExploitationNow': 'http://www.exploitationnow.com/',
        'FilthyLies': 'http://www.filthylies.net/',
        'FriendlyHostility': 'http://friendlyhostility.com/',
        'FunnyFarm': 'http://www.funnyfarmcomics.com/',
        'GamingGuardians': 'http://gamingguardians.com/',
        'GeneCatlow': 'http://www.genecatlow.com/',
        'GeneralProtectionFault': 'http://www.gpf-comics.com/',
        'Ghastly': 'http://www.ghastlycomic.com/',
        'GoblinHollow': 'http://utlt.keenspace.com/',
        'GreystoneInn': 'http://www.greystoneinn.net/',
        'InAPerfectWorld': 'http://iapw.keenspace.com/',
        'ItsWalky': 'http://www.itswalky.com/',
        'JoeAverage': 'http://www.joeaverage.org/',
        'LimitedSpace': 'http://www.limitedspace.org/',
        'LostAndFound': 'http://www.lostandfoundcomic.com/',
        'MariposaRevelation': 'http://mariposa.keenspace.com/',
        'MenInHats': 'http://www.meninhats.com/',
        'NaughtFramed': 'http://www.damonk.com/',
        'NekoTheKitty': 'http://nekothekitty.keenspace.com/',
        'NipAndTuck': 'http://nipandtuck.keenspace.com/',
        'OneOverZero': 'http://oneoverzero.keenspace.com/',
        'PurplePussy': 'http://www.purplepussy.net/',
        'QueenOfWands': 'http://www.queenofwands.net/',
        'RoadWaffles': 'http://www.roadwaffles.com/',
        'RPGWorld': 'http://www.rpgworldcomic.com/',
        'SaturdayMorningBreakfastCereal': 'http://smbc.keenspace.com/',
        'Saturnalia': 'http://saturnalia.keenspace.com/',
        'Scatterplot': 'http://scatterplot.keenspace.com/',
        'SchlockMercenary': 'http://www.schlockmercenary.com/',
        'Scrued': 'http://www.scrued.com/',
        'SinFest': 'http://www.sinfest.net/',
        'SkirtingDanger': 'http://www.skirtingdanger.com/',
        'SoreThumbs': 'http://www.sorethumbsonline.com/',
        'StrangeCandy': 'http://www.strangecandy.net/',
        'Striptease': 'http://www.stripteasecomic.com/',
        'Stubble': 'http://www.stubblecomics.com/',
        'TalesOfTheQuestor': 'http://npc.keenspace.com/',
        'TangsWeeklyComic': 'http://tang.keenspace.com/',
        'TAVision': 'http://tav.keenspace.com/',
        'TheNoob': 'http://thenoob.keenspace.com/',
        'TheShadows': 'http://www.alicecomics.com/shad',
        'UberSoft': 'http://www.ubersoft.net/',
        'WapsiSquare': 'http://www.wapsisquare.com/',
        'WorldOfFenninRo': 'http://wofr.keenspace.com/',
        'ZebraGirl': 'http://zebragirl.keenspot.com/',
        'Zortic': 'http://www.zortic.com/',
    }

    latestUrls = {
        'Alice': 'http://www.alicecomics.com/today.html',
        'DeltaVenture': 'http://www.alicecomics.com/adventure.html',
        'ElfLife': 'http://www.elflife.com/today.html',
        'TheShadows': 'http://www.alicecomics.com/shadows.html',
    }

    def __init__(self, submodule):
        BasicComicModule.__init__(self)
        baseUrl = self.submodules[submodule]
        self.latestUrl = self.latestUrls.get(submodule, baseUrl)
        self.imageUrl = baseUrl + self.imageUrl
        self.name = 'KeenSpot' + '/' + submodule

==> dosage_1.5.3.orig.tar.gz: dosage-1.5.3/dosage/modules/KeenSpot.py <==
import re
from dosage.modules.helpers.BasicComicModule import BasicComicModule

class KeenSpot(BasicComicModule):
    imageUrl = 'd/%s.html'
    imageSearch = re.compile(r'<img[^>]+?src="([^"]*?comics/.+?)"', re.IGNORECASE)
    prevSearch = re.compile(r'<a href="([^"]*?d/\d{8}\.html)">(?:<img[^>]+?(?:name="previous_day"|src="[^"]*back[^"]*")|Previous comic)', re.IGNORECASE)
    help = 'Index format: yyyymmdd'

    submodules = {
        '24fps': 'http://filmbuff.keenspace.com/',
        'Adventurers': 'http://www.adventurers-comic.com/',
        'Alice': 'http://www.alicecomics.com/',
        'AlienDice': 'http://www.aliendice.com/',
        'AlphaLuna': 'http://alphaluna.keenspace.com/',
        'AntiHeroForHire': 'http://www.antiheroforhire.com/',
        'Avalon': 'http://www.avalonhigh.com/',
        'BasilFlint': 'http://www.basilflint.com/',
        'Blindworks': 'http://blindworks.keenspace.com/',
        'BoomerExpress': 'http://boomerexpress.keenspace.com/',
        'BoyMeetsBoy': 'http://boymeetsboy.keenspot.com/',
        'CheckerboardNightmare': 'http://www.checkerboardnightmare.com/',
        'ChoppingBlock': 'http://choppingblock.org/',
        'ClanOfTheCats': 'http://www.clanofthecats.com/',
        'CollegeRoomiesFromHell': 'http://www.crfh.net/',
        'CountYourSheep': 'http://www.countyoursheep.com/',
        'DeltaVenture': 'http://www.alicecomics.com/adv',
        'DexLives': 'http://dexlives.keenspace.com/',
        'DominicDeegan': 'http://www.dominic-deegan.com/',
        'ElfLife': 'http://www.elflife.com/',
        'ElfOnlyInn': 'http://www.elfonlyinn.net/',
        'ElGoonishShive': 'http://elgoonishshive.com/',
        'ErrantStory': 'http://www.errantstory.com/',
        'EverythingJake': 'http://www.everythingjake.com/',
        'ExploitationNow': 'http://www.exploitationnow.com/',
        'FilthyLies': 'http://www.filthylies.net/',
        'FriendlyHostility': 'http://friendlyhostility.com/',
        'FunnyFarm': 'http://www.funnyfarmcomics.com/',
        'GamingGuardians': 'http://gamingguardians.com/',
        'GeneCatlow': 'http://www.genecatlow.com/',
        'GeneralProtectionFault': 'http://www.gpf-comics.com/',
        'Ghastly': 'http://www.ghastlycomic.com/',
        'GoblinHollow': 'http://utlt.keenspace.com/',
        'GreystoneInn': 'http://www.greystoneinn.net/',
        'InAPerfectWorld': 'http://iapw.keenspace.com/',
        'ItsWalky': 'http://www.itswalky.com/',
        'JoeAverage': 'http://www.joeaverage.org/',
        'LimitedSpace': 'http://www.limitedspace.org/',
        'LostAndFound': 'http://www.lostandfoundcomic.com/',
        'Lowroad75': 'http://lowroad75.keenspace.com/',
        'MariposaRevelation': 'http://mariposa.keenspace.com/',
        'MenInHats': 'http://www.meninhats.com/',
        'NaughtFramed': 'http://www.damonk.com/',
        'NekoTheKitty': 'http://nekothekitty.keenspace.com/',
        'NipAndTuck': 'http://nipandtuck.keenspace.com/',
        'OneOverZero': 'http://oneoverzero.keenspace.com/',
        'PurplePussy': 'http://www.purplepussy.net/',
        'QueenOfWands': 'http://www.queenofwands.net/',
        'RoadWaffles': 'http://www.roadwaffles.com/',
        'RPGWorld': 'http://www.rpgworldcomic.com/',
        'SaturdayMorningBreakfastCereal': 'http://smbc.keenspace.com/',
        'Saturnalia': 'http://saturnalia.keenspace.com/',
        'Scatterplot': 'http://scatterplot.keenspace.com/',
        'SchlockMercenary': 'http://www.schlockmercenary.com/',
        'Scrued': 'http://www.scrued.com/',
        'SinFest': 'http://www.sinfest.net/',
        'SkirtingDanger': 'http://www.skirtingdanger.com/',
        'SoreThumbs': 'http://www.sorethumbsonline.com/',
        'StrangeCandy': 'http://www.strangecandy.net/',
        'Striptease': 'http://www.stripteasecomic.com/',
        'Stubble': 'http://www.stubblecomics.com/',
        'TalesOfTheQuestor': 'http://npc.keenspace.com/',
        'TangsWeeklyComic': 'http://tang.keenspace.com/',
        'TAVision': 'http://tav.keenspace.com/',
        'TheNoob': 'http://thenoob.keenspace.com/',
        'TheShadows': 'http://www.alicecomics.com/shad',
        'TonjaSteele': 'http://tonjasteele.keenspace.com/',
        'UberSoft': 'http://www.ubersoft.net/',
        'WapsiSquare': 'http://www.wapsisquare.com/',
        'Werechild': 'http://werechild.keenspace.com',
        'WorldOfFenninRo': 'http://wofr.keenspace.com/',
        'ZebraGirl': 'http://zebragirl.keenspot.com/',
        'Zortic': 'http://www.zortic.com/',
    }

    latestUrls = {
        'Alice': 'http://www.alicecomics.com/today.html',
        'DeltaVenture': 'http://www.alicecomics.com/adventure.html',
        'ElfLife': 'http://www.elflife.com/today.html',
        'TheShadows': 'http://www.alicecomics.com/shadows.html',
    }

    def __init__(self, submodule):
        BasicComicModule.__init__(self)
        baseUrl = self.submodules[submodule]
        self.latestUrl = self.latestUrls.get(submodule, baseUrl)
        self.imageUrl = baseUrl + self.imageUrl
        self.name = 'KeenSpot' + '/' + submodule
